@@ -18,37 +18,40 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Standard Python modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....const import GRAMPS_LOCALE as glocale
+
 _ = glocale.translation.gettext
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 #
 # Gramps modules
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 from ....utils.db import for_each_ancestor
 from ._hascommonancestorwith import HasCommonAncestorWith
 from ._matchesfilter import MatchesFilter
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # HasCommonAncestorWithFilterMatch
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 class HasCommonAncestorWithFilterMatch(HasCommonAncestorWith):
     """Rule that checks for a person that has a common ancestor with
     someone matching a filter"""
 
-    labels      = [ _('Filter name:') ]
-    name        = _('People with a common ancestor with <filter> match')
-    description = _("Matches people that have a common ancestor "
-                    "with anybody matched by a filter")
-    category    = _("Ancestral filters")
+    labels = [_("Filter name:")]
+    name = _("People with a common ancestor with <filter> match")
+    description = _(
+        "Matches people that have a common ancestor " "with anybody matched by a filter"
+    )
+    category = _("Ancestral filters")
 
     def __init__(self, list, use_regex=False):
         HasCommonAncestorWith.__init__(self, list, use_regex)
@@ -62,22 +65,27 @@ class HasCommonAncestorWithFilterMatch(HasCommonAncestorWith):
         # Start with filling the cache for root person (gramps_id in self.list[0])
         self.ancestor_cache = {}
         self.with_people = []
-        filt = MatchesFilter(self.list)
-        filt.requestprepare(db, user)
+        self.filt = MatchesFilter(self.list)
+        self.filt.requestprepare(db, user)
         if user:
-            user.begin_progress(self.category,
-                                _('Retrieving all sub-filter matches'),
-                                db.get_number_of_people())
+            user.begin_progress(
+                self.category,
+                _("Retrieving all sub-filter matches"),
+                db.get_number_of_people(),
+            )
         for handle in db.iter_person_handles():
             person = db.get_person_from_handle(handle)
             if user:
                 user.step_progress()
-            if person and filt.apply(db, person):
-                #store all people in the filter so as to compare later
+            if person and self.filt.apply(db, person):
+                # store all people in the filter so as to compare later
                 self.with_people.append(person.handle)
-                #fill list of ancestor of person if not present yet
+                # fill list of ancestor of person if not present yet
                 if handle not in self.ancestor_cache:
                     self.add_ancs(db, person)
         if user:
             user.end_progress()
-        filt.requestreset()
+
+    def reset(self):
+        self.filt.requestreset()
+        self.ancestor_cache = {}
