@@ -23,12 +23,13 @@ Location utility functions
 """
 from ..lib.date import Date, Today
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # get_location_list
 #
-#-------------------------------------------------------------------------
-def get_location_list(db, place, date=None, lang=''):
+# -------------------------------------------------------------------------
+def get_location_list(db, place, date=None, lang=""):
     """
     Return a list of place names for display.
     """
@@ -52,6 +53,7 @@ def get_location_list(db, place, date=None, lang=''):
         lines.append((__get_name(place, date, lang), place.get_type()))
     return lines
 
+
 def __get_name(place, date, lang):
     endonym = None
     for place_name in place.get_all_names():
@@ -61,7 +63,8 @@ def __get_name(place, date, lang):
                 return place_name.get_value()
             if endonym is None:
                 endonym = place_name.get_value()
-    return endonym if endonym is not None else '?'
+    return endonym if endonym is not None else "?"
+
 
 def __get_latest_date(place):
     latest_date = None
@@ -79,56 +82,63 @@ def __get_latest_date(place):
                 latest_date = date
     return latest_date
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # get_main_location
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 def get_main_location(db, place, date=None):
     """
     Find all places in the hierarchy above the given place, and return the
     result as a dictionary of place types and names.
     """
-    return dict([(int(place_type), name)
-                    for name, place_type
-                    in get_location_list(db, place, date)
-                    if not place_type.is_custom()])
+    return dict(
+        [
+            (int(place_type), name)
+            for name, place_type in get_location_list(db, place, date)
+            if not place_type.is_custom()
+        ]
+    )
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # get_locations
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 def get_locations(db, place):
     """
     Determine each possible route up the place hierarchy, and return a list
     containing dictionaries of place types and names.
     """
     locations = []
-    todo = [(place, [(int(place.get_type()), __get_all_names(place))],
-            [place.handle])]
+    todo = [(place, [(int(place.get_type()), __get_all_names(place))], [place.handle])]
     while len(todo):
         place, tree, visited = todo.pop()
         for parent in place.get_placeref_list():
             if parent.ref not in visited:
                 parent_place = db.get_place_from_handle(parent.ref)
                 if parent_place is not None:
-                    parent_tree = tree + [(int(parent_place.get_type()),
-                                           __get_all_names(parent_place))]
+                    parent_tree = tree + [
+                        (int(parent_place.get_type()), __get_all_names(parent_place))
+                    ]
                     parent_visited = visited + [parent.ref]
                     todo.append((parent_place, parent_tree, parent_visited))
         if len(place.get_placeref_list()) == 0:
             locations.append(dict(tree))
     return locations
 
+
 def __get_all_names(place):
     return [name.get_value() for name in place.get_all_names()]
 
-#-------------------------------------------------------------------------
+
+# -------------------------------------------------------------------------
 #
 # located_in
 #
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------
 def located_in(db, handle1, handle2):
     """
     Determine if the place identified by handle1 is located within the place
